import { EffectCallback, DependencyList } from 'react';
/**
 * This hook gets called only when the dependencies change but not during initial render.
 *
 * @param {EffectCallback} effect The `useEffect` callback function.
 * @param {DependencyList} deps An array of dependencies.
 *
 * @example
 * ```
 *  useNonInitialEffect(()=>{
 *      alert("Dependency changed!");
 * },[dependency]);
 * ```
 */
export declare const useNonInitialEffect: (effect: EffectCallback, deps?: DependencyList | undefined) => void;
