"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useNonInitialEffect = void 0;
const react_1 = require("react");
/**
 * This hook gets called only when the dependencies change but not during initial render.
 *
 * @param {EffectCallback} effect The `useEffect` callback function.
 * @param {DependencyList} deps An array of dependencies.
 *
 * @example
 * ```
 *  useNonInitialEffect(()=>{
 *      alert("Dependency changed!");
 * },[dependency]);
 * ```
 */
const useNonInitialEffect = (effect, deps) => {
    const initialRender = react_1.useRef(true);
    react_1.useEffect(() => {
        let effectReturns;
        if (initialRender.current) {
            initialRender.current = false;
        }
        else {
            effectReturns = effect();
        }
        if (effectReturns && typeof effectReturns === 'function') {
            return effectReturns;
        }
    }, deps);
};
exports.useNonInitialEffect = useNonInitialEffect;
