"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.interactive = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const ink_1 = require("ink");
const getFiles_1 = require("./getFiles");
const Monitor_1 = require("./components/Monitor");
const From_1 = require("./components/From");
const utils_1 = require("./utils");
const DEFAULT_PATTERN = '**';
const memoizedGetFiles = utils_1.memoize(getFiles_1.getFiles);
const interactive = async ({ initialPattern, initialSearch, initialReplace, }) => {
    return new Promise((resolve, reject) => {
        let clear;
        const App = () => {
            const { exit } = ink_1.useApp();
            const [state, setState] = react_1.useState({
                files: [],
                searchRegExp: null,
                replace: null,
                searchError: null,
                patternError: null,
            });
            const { files, searchRegExp, replace, searchError, patternError } = state;
            const matches = getMatches(files, searchRegExp);
            react_1.useEffect(() => {
                updateFiles(initialPattern);
            }, []);
            const updateFiles = (p) => {
                if (!p)
                    p = DEFAULT_PATTERN;
                memoizedGetFiles(p)
                    .then((f) => {
                    setState({ ...state, patternError: null, files: f });
                })
                    .catch((error) => {
                    setState({ ...state, patternError: error.message, files: [] });
                });
            };
            return (jsx_runtime_1.jsxs(jsx_runtime_1.Fragment, { children: [jsx_runtime_1.jsx(From_1.Form, { onExit: () => {
                            clear();
                            exit();
                            reject('abort');
                        }, onSubmit: ({ inputs }) => {
                            clear();
                            exit();
                            const [pattern, search, replace] = inputs;
                            resolve({ pattern, search, replace });
                        }, inputs: [
                            {
                                placeholder: '**',
                                label: 'Pattern',
                                initialValue: initialPattern,
                                validationError: patternError,
                                onChange: (newInput) => {
                                    updateFiles(newInput);
                                },
                            },
                            {
                                label: 'Search ',
                                initialValue: initialSearch,
                                validationError: searchError,
                                onChange: (newInput) => {
                                    if (!newInput) {
                                        setState({
                                            ...state,
                                            searchRegExp: null,
                                            searchError: null,
                                        });
                                        return;
                                    }
                                    try {
                                        setState({
                                            ...state,
                                            searchRegExp: new RegExp(newInput),
                                            searchError: null,
                                        });
                                    }
                                    catch (error) {
                                        setState({
                                            ...state,
                                            searchRegExp: null,
                                            searchError: error.message,
                                        });
                                    }
                                },
                            },
                            {
                                label: 'Replace',
                                initialValue: initialReplace,
                                onChange: (newInput) => {
                                    setState({
                                        ...state,
                                        replace: newInput !== null && newInput !== void 0 ? newInput : null,
                                    });
                                },
                            },
                        ] }, void 0),
                    jsx_runtime_1.jsx(Monitor_1.Monitor, { files: files, searchRegExp: searchRegExp, matches: matches, replace: replace }, void 0)] }, void 0));
        };
        const inkRenderApi = ink_1.render(jsx_runtime_1.jsx(App, {}, void 0), { exitOnCtrlC: false });
        clear = inkRenderApi.clear;
    });
};
exports.interactive = interactive;
const getMatches = (files, searchRegexp) => {
    if (!searchRegexp)
        return [];
    const matches = [];
    for (const filePath of files) {
        const result = searchRegexp.exec(filePath);
        if (result) {
            const match = result[0];
            const matchStartIndex = result.index;
            matches.push({ filePath, match, matchStartIndex });
        }
    }
    return matches;
};
